@@ -96,6 +96,7 @@ static struct { const char* lopt; const char opt; const char *arg; const char *h
 	{"version",	'v', NULL,	N_("displays the version")},
 	{"arrow-cursor", 'a', NULL, 	N_("use an arrow cursor instead of reverse video")},
 	{"new-table",	'z', NULL,	N_("create a new partition table on the disk")},
+	{"align",	'A', N_("TYPE"),N_("use align TYPE, can be none, cyl, min or opt")},
 	{"units",	'u', N_("UNIT"),N_("sets the default display units to UNIT")},
 	{"list-partition-types", 't', NULL, N_("displays a list of supported partition types")},
         {NULL, 0, NULL, NULL}
@@ -485,7 +486,7 @@ menu_draw (const MenuItem *items, int item_len, MenuOptions opts, const char *ke
 }
 
 /* TODO: Not perfect */
-static is_key_ok (int key, const char* ok_keys, MenuOptions opts) {
+static int is_key_ok (int key, const char* ok_keys, MenuOptions opts) {
 
 	if (opts & MENU_ARROWS) {
 		switch (key) {
@@ -1015,7 +1016,7 @@ _timer_handler (PedTimer* timer, void* context) {
 		else
 			snprintf(buf,SMALLBUF,_("An operation is now taking place."));
 		set_status(buf,0);
-		snprintf(buf,SMALLBUF,_("Progress: %3.1f%%   Time left: %4.2d:%.2d"),
+		snprintf(buf,SMALLBUF,_("Progress: %3.1f%%   Time left: %4.2ld:%.2ld"),
 		         100.0 * timer->frac,
 		         tcontext->predicted_time_left / 60,
 		         tcontext->predicted_time_left % 60); 
@@ -1076,10 +1077,12 @@ _disk_reread(Context *c, PedPartition **part) {
 	}
 	ped_disk_destroy(c->disk);
 	c->disk = ped_disk_new(c->dev);
+	init_disk_flags(c->disk);
 	uiquery.need_commit = 0;
 	if (part) {
 		*part = ped_disk_get_partition(c->disk,partnum);
 	}
+	return 1;
 }
 
 
@@ -1118,7 +1121,7 @@ do_new (Context *c, PedPartition **part) {
 	type_keys[i++] = 'b'; /* The BSD disklabel can be counted as a regular partition */
 	PedPartitionType type = 0;
 	PartPos pos;
-	int key,success = 1,done;
+	int key;
 	UIOpts opts = UI_DEFAULT;
 	if (!((*part)->type & PED_PARTITION_FREESPACE)) {
 		warning_waitkey(N_("Report a bug in the function menu_new and win a cookie."));
@@ -1177,9 +1180,8 @@ do_new (Context *c, PedPartition **part) {
 	return 1;	
 }
 
-do_edit (Context *c, PedPartition **part) {
+int do_edit (Context *c, PedPartition **part) {
 	char devname[SMALLBUF];
-	PedDevice *dev;
 	if (uiquery.need_commit) {
 	        ped_exception_throw (
 				     PED_EXCEPTION_ERROR,
@@ -1224,6 +1226,7 @@ do_edit (Context *c, PedPartition **part) {
 	/* We reset this back to its default state */
 	uiquery.need_commit = 0;
 	ped_device_end_external_access(c->disk->dev);
+	return 1;
 }
 static int
 do_resize (Context *c, PedPartition **part) {
@@ -1248,7 +1251,7 @@ do_resize (Context *c, PedPartition **part) {
 	PedFileSystem *fs = NULL;
 	PedSector first,last;
 	PartPos pos;
-	UIOpts opts = UI_WARN_COMMIT;
+	UIOpts opts = UI_WARN_COMMIT | UI_SNAP_TO_START;
 	if (!((*part)->type & PED_PARTITION_EXTENDED)) {
 		if ((*part)->fs_type && (*part)->fs_type->ops->resize) {
 			menu_title(_("What do you want to do?"));
@@ -1279,7 +1282,6 @@ do_resize (Context *c, PedPartition **part) {
 			opts |= UI_NO_FS_RESIZE;
 		}
 	}
-	char buf[SMALLBUF];
 
 	pos.start.sector = (*part)->geom.start;
 	pos.end.sector = (*part)->geom.end;
@@ -1437,8 +1439,6 @@ do_rescue(Context *c, PedPartition **part) {
 	};
 	const char keys[] = { 'g', 'c', ESC, '\0' };
 	int key;
-	PedPartition *temp;
-
 
 	menu_title(_("This will try to rescue broken or deleted partitions")); 
 	key = do_menu(rescue_menu, 8, MENU_BUTTON | MENU_TITLE, keys, NULL);
@@ -1522,7 +1522,7 @@ do_minimize(Context *c, PedPartition **part) {
 	if (temp && temp->type & PED_PARTITION_FREESPACE)
 		temp = disk_get_prev_nmd_partition(c->disk, temp); 
 
-	if (!(*part)->type & PED_PARTITION_EXTENDED)
+	if (((*part)->type & PED_PARTITION_EXTENDED) == 0)
 		return 0;
 	if (!ped_disk_minimize_extended_partition(c->disk)) {
 		warning_waitkey(N_("Couldn't minimize the extended partition"));
@@ -1589,6 +1589,9 @@ do_units () {
 		case 'C': ped_unit_set_default(PED_UNIT_CHS); return 1;
 		
 	}
+
+	 ped_unit_set_default(PED_UNIT_CYLINDER);
+	return 0;
 }
 
 /* I'm not quite sure we should let the user do this... */
@@ -1655,7 +1658,6 @@ printaflag (int *y, const PedPartition *part, PedPartitionFlag flag, PedPartitio
 		{ 0, NULL }
 	};
 #endif
-	int i;
 
 	if (!ped_partition_is_flag_available(part,flag))
 		return;
@@ -2241,10 +2243,10 @@ main_plist(Context *c, PedPartition **part, int key) {
    have and havent aren't perfect, but work for our purposes */
 static int
 do_plist (Context *c, PedPartition **part, PedPartitionType have, PedPartitionType havent) {
-	int key = 0, i, redraw = 1, selnum = 0, start = 0;
+	int key = 0, redraw = 1, selnum = 0, start = 0;
 	const char* keys;
 	PedPartition *selected = NULL;
-	PedPartition *temp,*memp;
+	PedPartition *temp;
 	MenuOptions menu_opts = MENU_BUTTON | MENU_ARROWS;
 	MenuItem *part_menu;
 	int menupos = 0;
@@ -2446,6 +2448,8 @@ init_disk(int new_table, char *devname, PedDevice *dev, PedDiskType *type) {
 			else do_quit (0,NULL);
 		} else {
 			ped_exception_leave_all();
+			if (!init_disk_flags(disk))
+				do_quit(1,_("Internal error initializing disk flags"));
 		}
 	} else {
 		if (!perform_mklabel (dev, &disk, NULL))
@@ -2482,7 +2486,7 @@ init_disk(int new_table, char *devname, PedDevice *dev, PedDiskType *type) {
 	}
 	
 	snprintf(buf,SMALLBUF,"%lldB/%lldB\n",dev->sector_size, dev->phys_sector_size);
-	n = strnlen(buf);
+	n = strlen(buf);
 	context->info_sectorsize = calloc(n,sizeof(char));
 	strncpy(context->info_sectorsize,buf,n);
 
@@ -2536,7 +2540,7 @@ static void
 print_usage() {
 	int i;
 	char buf[SMALLBUF];
-	printf(_(usage_msg));
+	fputs(_(usage_msg), stdout);
 	printf("\n%s\n",_("OPTIONs:"));
 	for (i = 0; options_help[i].opt; i++) {
 		if (options_help[i].arg)
@@ -2551,8 +2555,8 @@ print_usage() {
 
 static void
 print_version() {
-	printf(prog_name);
-	printf(_(license_msg));
+	fputs(prog_name, stdout);
+	fputs(_(license_msg), stdout);
 	exit(0);
 }
 
@@ -2560,12 +2564,14 @@ int
 main (int argc, char **argv) {
 	PedUnit unit = -1;
 	char *devname;
+	AlignType align_type;
 	PedDevice *dev;
 #ifdef HAVE_GETOPT_H
 	static struct option long_options[] = {
 		{ "new-table", no_argument, NULL, 'z' },
 		{ "version", no_argument, NULL, 'v' },
 		{ "arrow-cursor", no_argument, NULL, 'a' },
+		{ "align", required_argument, NULL, 'A' },
 		{ "units", required_argument, NULL, 'u' },
 		{ "help", no_argument, NULL, 'h' },
 		{ "list-partition-types", no_argument, NULL, 't' },
@@ -2573,10 +2579,10 @@ main (int argc, char **argv) {
 	};
 
 	int opt,option_index;
-	while ((opt = getopt_long(argc,argv, "hazvtu:", long_options, &option_index)) != -1) {
+	while ((opt = getopt_long(argc,argv, "hazvtA:u:", long_options, &option_index)) != -1) {
 #else
 	int opt;
-	while ((opt = getopt(argc,argv,"hazvtu:")) != -1) {
+	while ((opt = getopt(argc,argv,"hazvtA:u:")) != -1) {
 #endif		
 		switch (opt) {
 			case 'v':
@@ -2591,6 +2597,12 @@ main (int argc, char **argv) {
 			case 'z': 
 				new_table = 1;
 				break;
+			case 'A':
+				align_type = string_to_align_type(optarg);
+				if (align_type == ALIGNMENT_INVALID)
+					print_usage();
+				current_partition_align_type = align_type;
+				break;
 			case 'u':
 				unit = ped_unit_get_by_name(optarg);
 				break;
@@ -2623,4 +2635,5 @@ main (int argc, char **argv) {
 		exit(1);
 	}
 	do_ui(devname, dev);
+	return 0;
 }
